@@ -76,15 +76,15 @@ def style(sample: str,
         sample = re.sub(r'([]}]),(?!\n)', r'\1,\n', sample)
         sample = re.sub(r'(?<!\[)],(?![\n\[])', '],\n', sample)
     elif bracket_wrap == BracketWrap.INLINE_STACKED:
-        sample = re.sub(r'{(?![}[])', '{\n', sample)
+        sample = re.sub(r'{(?![}\[])', '{\n', sample)
         sample = re.sub(r'\[(?![\[\]{])', '[\n', sample)
         sample = re.sub(r'(?<![{\]])}', '\n}', sample)
-        sample = re.sub(r'(?<![[}])]', '\n]', sample)
+        sample = re.sub(r'(?<![\[}])]', '\n]', sample)
         sample = re.sub(r'([]}]),<', r'\1,\n<', sample)
     elif bracket_wrap == BracketWrap.FORCE_LINEBREAK:
-        sample = re.sub(r'([[{])(?![]}])', r'\n\1', sample)
-        sample = re.sub(r'(?<![[{])([]}])', r'\n\1', sample)
-        sample = re.sub(r'([[{])(?=<)', r'\1\n', sample)
+        sample = re.sub(r'([\[{])(?![]}])', r'\n\1', sample)
+        sample = re.sub(r'(?<![\[{])([]}])', r'\n\1', sample)
+        sample = re.sub(r'([\[{])(?=<)', r'\1\n', sample)
         sample = re.sub(r'([]}]),<', r'\1,\n<', sample)
         sample = re.sub(r'(?<!\[)],(?![\n\[])', '],\n', sample)
     # Add a newline after bracket pairs.
@@ -132,12 +132,14 @@ def scramble(sample: str,
         that are not to be changed, default [('"', '"')].
     :return: The sample string with random whitespace.
     """
-    preserve_blocks = preserve_blocks or [('"', '"')]
+    escaped_escapes = re.compile(r'\\{2}')
+    escapes, escapes_mark, sample = depopulate(escaped_escapes, sample)
     # Remove all blocks that are to be preserved.
+    preserve_blocks = preserve_blocks or [('"', '"')]
     blk_matches_lists: List[List[str]] = []
     blk_markers: List[str] = []
     for opener, closer in preserve_blocks:
-        pattern = re.compile(fr'{opener}.*?{closer}', re.M)
+        pattern = re.compile(fr'{opener}.*?(?<!\\){closer}', re.M)
         mat, mark, sample = depopulate(pattern, sample)
         blk_matches_lists.append(mat)
         blk_markers.append(mark)
@@ -171,4 +173,21 @@ def scramble(sample: str,
     # Repopulate the preserved blocks.
     for i in range(len(blk_markers)):
         sample = repopulate(blk_matches_lists[i], blk_markers[i], sample)
+    sample = repopulate(escapes, escapes_mark, sample)
+    return sample
+
+
+def compress(sample: str) -> str:
+    """Remove all extra whitespace from a JSON string.
+
+    :param sample: Sample JSON to remove whitespace from.
+    :return: A single line JSON string.
+    """
+    escaped_escapes = re.compile(r'\\{2}')
+    escapes, escapes_mark, sample = depopulate(escaped_escapes, sample)
+    quote_reg = re.compile(r'".*?(?<!\\)"')
+    quotes, quotes_mark, sample = depopulate(quote_reg, sample)
+    sample = re.sub(r'\s*', '', sample)
+    sample = repopulate(quotes, quotes_mark, sample)
+    sample = repopulate(escapes, escapes_mark, sample)
     return sample
